@@ -11,6 +11,7 @@ from itertools import dropwhile
 
 import django
 from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
 from django.core.files.temp import NamedTemporaryFile
 from django.core.management.base import BaseCommand, CommandError
 from django.core.management.utils import (
@@ -21,6 +22,7 @@ from django.utils.encoding import DEFAULT_LOCALE_ENCODING, force_str
 from django.utils.functional import cached_property
 from django.utils.jslex import prepare_js_for_gettext
 from django.utils.text import get_text_list
+from django.utils.translation import templatize
 
 plural_forms_re = re.compile(r'^(?P<value>"Plural-Forms.+?\\n")\s*$', re.MULTILINE | re.DOTALL)
 STATUS_OK = 0
@@ -44,7 +46,10 @@ class TranslatableFile(object):
         self.locale_dir = locale_dir
 
     def __repr__(self):
-        return "<TranslatableFile: %s>" % os.sep.join([self.dirpath, self.file])
+        return "<%s: %s>" % (
+            self.__class__.__name__,
+            os.sep.join([self.dirpath, self.file]),
+        )
 
     def __eq__(self, other):
         return self.path == other.path
@@ -99,18 +104,17 @@ class BuildFile(object):
         Preprocess (if necessary) a translatable file before passing it to
         xgettext GNU gettext utility.
         """
-        from django.utils.translation import templatize
-
         if not self.is_templatized:
             return
 
-        with io.open(self.path, 'r', encoding=settings.FILE_CHARSET) as fp:
+        encoding = settings.FILE_CHARSET if self.command.settings_available else 'utf-8'
+        with io.open(self.path, 'r', encoding=encoding) as fp:
             src_data = fp.read()
 
         if self.domain == 'djangojs':
             content = prepare_js_for_gettext(src_data)
         elif self.domain == 'django':
-            content = templatize(src_data, self.path[2:])
+            content = templatize(src_data, origin=self.path[2:], charset=encoding)
 
         with io.open(self.work_path, 'w', encoding='utf-8') as fp:
             fp.write(content)
@@ -277,12 +281,6 @@ class Command(BaseCommand):
         extensions = options['extensions']
         self.symlinks = options['symlinks']
 
-        # Need to ensure that the i18n framework is enabled
-        if settings.configured:
-            settings.USE_I18N = True
-        else:
-            settings.configure(USE_I18N=True)
-
         ignore_patterns = options['ignore_patterns']
         if options['use_default_ignore_patterns']:
             ignore_patterns += ['CVS', '.*', '*~', '*.pyc']
@@ -332,7 +330,8 @@ class Command(BaseCommand):
             self.default_locale_path = self.locale_paths[0]
             self.invoked_for_django = True
         else:
-            self.locale_paths.extend(settings.LOCALE_PATHS)
+            if self.settings_available:
+                self.locale_paths.extend(settings.LOCALE_PATHS)
             # Allow to run makemessages inside an app dir
             if os.path.isdir('locale'):
                 self.locale_paths.append(os.path.abspath('locale'))
@@ -384,6 +383,16 @@ class Command(BaseCommand):
         else:
             raise CommandError("Unable to get gettext version. Is it installed?")
 
+    @cached_property
+    def settings_available(self):
+        try:
+            settings.LOCALE_PATHS
+        except ImproperlyConfigured:
+            if self.verbosity > 1:
+                self.stderr.write("Running without configured settings.")
+            return False
+        return True
+
     def build_potfiles(self):
         """
         Build pot files and apply msguniq to them.
@@ -445,7 +454,9 @@ class Command(BaseCommand):
                 norm_patterns.append(p)
 
         all_files = []
-        ignored_roots = [os.path.normpath(p) for p in (settings.MEDIA_ROOT, settings.STATIC_ROOT) if p]
+        ignored_roots = []
+        if self.settings_available:
+            ignored_roots = [os.path.normpath(p) for p in (settings.MEDIA_ROOT, settings.STATIC_ROOT) if p]
         for dirpath, dirnames, filenames in os.walk(root, topdown=True, followlinks=self.symlinks):
             for dirname in dirnames[:]:
                 if (is_ignored(os.path.normpath(os.path.join(dirpath, dirname)), norm_patterns) or
